Synthetic multivariate data with spatial and non-spatial variance structures
FBC07.dat.RdThe synthetic dataset describes a stationary and isotropic bivariate process. Please refer to the vignette Section 4.2 for specifics.
Usage
data(FBC07.dat)
FBC07.dat.RdThe synthetic dataset describes a stationary and isotropic bivariate process. Please refer to the vignette Section 4.2 for specifics.
data(FBC07.dat)