Learn R Programming

spBayes (version 0.0-1)

sp.DIC: Calculates Deviance Information Criterion (DIC) for ggt.sp object

Description

The function sp.DIC calculates DIC and associated statistics for a given ggt.sp object.

Usage

sp.DIC(ggt.sp.obj, start=1, end, thin=1, verbose=TRUE, ...)

Arguments

ggt.sp.obj
an object returned by ggt.sp (i.e., object of class ggt.sp).
start
specifies the first sample included in the DIC calculation. This is useful for those who choose to acknowledge chain burn-in.
end
specifies the last sample included in the DIC calculation. The default is to include from start to nrow(ggt.sp.obj$p.samples).
thin
a sample thinning factor. The default of 1 considers all samples between start and end. For example, if thin = 10 then 1 in 10 samples are considered between start and end.
verbose
if TRUE calculation progress is printed to the screen. Otherwise, nothing is printed to the screen.
...
currently no additional arguments.

Value

  • DICa matrix that holds $DIC$ and associated values $\bar{D}$, $D[\bar{\theta}]$, and $pD$ (Banerjee et al. 2004 and Spiegelhalter et al. 2002).

References

Banerjee, S., Carlin, B.P., and Gelfand, A.E. (2004). Hierarchical modeling and analysis for spatial data. Chapman and Hall/CRC Press, Boca Raton, Fla. Spiegelhalter, D.J., Best, N., Carlin, B.P., and van der Linde, A. (2002). Bayesian measures of model complexity and fit (with discussion). J. Roy. Statist. Soc., Ser. B, 64, 583-639.

Further information on the package spBayes can be found at: http://blue.fr.umn.edu/spatialBayes.

See Also

ggt.sp