Learn R Programming

spBayes (version 0.3-9)

mkMvX: Make a multivariate design matrix

Description

Given $q$ univariate design matrices, the function mkMvX creates a multivariate design matrix suitable for use in spPredict.

Usage

mkMvX(X)

Arguments

X
a list of $q$ univariate design matrices. The matrices must have the same number of rows (i.e., observations) but may have different number of columns (i.e., regressors).

Value

A multivariate design matrix suitable for use in spPredict.

See Also

spPredict

Examples

Run this code
## Not run: 
# ##Define some univariate model design matrices
# ##with intercepts.
# X.1 <- cbind(rep(1, 10), matrix(rnorm(50), nrow=10))
# X.2 <- cbind(rep(1, 10), matrix(rnorm(20), nrow=10))
# X.3 <- cbind(rep(1, 10), matrix(rnorm(30), nrow=10))
# 
# ##Make a multivariate design matrix suitable
# ##for use in spPredict.
# X.mv <- mkMvX(list(X.1, X.2, X.3))
# ## End(Not run)

Run the code above in your browser using DataLab