prior creates a valid prior definition for use in ggt.sp.prior(dist, ...)"IG", uniform "UNIF",
log-uniform, "LOGUNIF", half-Cauchy "HC", normal
"NORMAL", flat ggt.prior which is used for the value portion of the prior tag in
the ggt.sp function.ggt.sp"a", and "b". }
"a", and "b". }
"shape", and "scale". }
"a". }
"mu" and "precision". } "df" and "S". }
Gelman, A. (2006). Prior distributions for variance parameters in
hierarchical models 1(3):515-533, Bayesian Analysis.
Further information on the package
ggt.sp